@@ -92,7 +92,7 @@ class VerbRegexURLPattern(RerouteRegexURLPattern):
         # patterns are resolved outside the context of a request.
         
         method_callbacks_by_regex = self.patterns_index.setdefault(patterns_id, {})
-        method_callbacks = method_callbacks_by_regex.setdefault(self.regex, {})
+        method_callbacks = method_callbacks_by_regex.setdefault(self.regex.pattern, {})
         
         if self.method not in method_callbacks:
             method_callbacks[self.method] = {'callback': self.callback, 'default_args': self.default_args}
@@ -103,4 +103,4 @@ class VerbRegexURLPattern(RerouteRegexURLPattern):
 
 def verb_url(method, regex, view, kwargs=None, name=None, prefix=''):
     pattern_class = partial(VerbRegexURLPattern, method)
-    return url_with_pattern_class(pattern_class, regex, view, kwargs, name, prefix)
\ No newline at end of file
+    return url_with_pattern_class(pattern_class, regex, view, kwargs, name, prefix)
